/*
 * $Id: RNTimerRelay.h 97832 2004-05-18 19:50:09Z grobbins $
 *
 * RNTimerRelay: Utility class serving as a Timer target and relaying to an owner.
 *               This prevents the owner from being retain'd by the Timer.
 *
 * Author:   Mac Team
 *           RealNetworks, Inc (C) 1999-2003, All rights reserved
 *
 */

#import <Cocoa/Cocoa.h>

@interface RNTimerRelay : NSObject
{
	id target;
	SEL selector;
	NSTimer* timer;
}
+ (RNTimerRelay *)timerWithTimeInterval:(NSTimeInterval)ti target:(id)aTarget selector:(SEL)aSelector userInfo:(id)userInfo repeats:(BOOL)yesOrNo;
+ (RNTimerRelay *)scheduledTimerWithTimeInterval:(NSTimeInterval)ti target:(id)aTarget selector:(SEL)aSelector userInfo:(id)userInfo repeats:(BOOL)yesOrNo;

- (id)initWithTarget:(id)aTarget selector:(SEL)aSelector;

- (void)setTimer:(NSTimer *)aTimer;
- (NSTimer *)timer;

- (void)timerFired:(NSTimer *)aTimer;

- (void)invalidate;
- (BOOL)isValid;

@end

@protocol RNTransitionTimerUser
- (void)transitionTimerFired:(NSTimer *)aTimer currentValue:(double)value isFinalCall:(BOOL)isLastCall;
@end

@interface RNTransitionTimerRelay : RNTimerRelay
{
	NSDate* transitionEndTime;
	NSTimeInterval transitionDuration;
	double startValue;
	double endValue;
}

+ (RNTransitionTimerRelay *)timerForTransitionDuration:(NSTimeInterval)duration 
										callbackPeriod:(NSTimeInterval)period
												target:(id <RNTransitionTimerUser>)aTarget 
											startValue:(double)theStartValue 
											  endValue:(double)theEndValue 
											  userInfo:(id)userInfo;
@end
